<?php
/**
 * The template for adding Logo Slider Options in Customizer
 *
 * @package Catch Themes
 * @subpackage Parallax Frame Pro
 * @since Parallax Frame 1.0
 */

//Logo Slider
$wp_customize->add_section( 'parallax_frame_logo_slider', array(
	'priority'		=> 900,
	'title'			=> esc_html__( 'Logo Slider', 'parallax-frame-pro' ),
) );

$wp_customize->add_setting( 'parallax_frame_theme_options[logo_slider_option]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['logo_slider_option'],
	'sanitize_callback' => 'parallax_frame_sanitize_select',
) );

$logo_slider_options = parallax_frame_featured_slider_content_options();
$choices = array();
foreach ( $logo_slider_options as $logo_slider_option ) {
	$choices[$logo_slider_option['value']] = $logo_slider_option['label'];
}

$wp_customize->add_control( 'parallax_frame_theme_options[logo_slider_option]', array(
	'choices'  => $choices,
	'label'    => esc_html__( 'Enable Logo Slider on', 'parallax-frame-pro' ),
	'section'  => 'parallax_frame_logo_slider',
	'settings' => 'parallax_frame_theme_options[logo_slider_option]',
	'type'     => 'select',
) );

$wp_customize->add_setting( 'parallax_frame_theme_options[logo_slider_bg]', array(
	'capability'        => 'edit_theme_options',
	'default'           => $defaults['logo_slider_bg'],
	'sanitize_callback' => 'parallax_frame_sanitize_image',
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'parallax_frame_theme_options[logo_slider_bg]', array(
	'active_callback' => 'parallax_frame_is_logo_slider_active',
	'label'           => esc_html__( 'Logo Slider Background Image', 'parallax-frame-pro' ),
	'section'         => 'parallax_frame_logo_slider',
	'settings'        => 'parallax_frame_theme_options[logo_slider_bg]',
) ) );

$wp_customize->add_setting( 'parallax_frame_theme_options[logo_slider_type]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['logo_slider_type'],
	'sanitize_callback' => 'parallax_frame_sanitize_select',
) );

$logo_slider_types = parallax_frame_logo_slider_types();
$choices = array();
foreach ( $logo_slider_types as $logo_slider_type ) {
	$choices[$logo_slider_type['value']] = $logo_slider_type['label'];
}

$wp_customize->add_control( 'parallax_frame_theme_options[logo_slider_type]', array(
	'active_callback' => 'parallax_frame_is_logo_slider_active',
	'choices'         => $choices,
	'label'           => esc_html__( 'Logo Slider Type', 'parallax-frame-pro' ),
	'section'         => 'parallax_frame_logo_slider',
	'settings'        => 'parallax_frame_theme_options[logo_slider_type]',
	'type'            => 'select',
) );

$wp_customize->add_setting( 'parallax_frame_theme_options[logo_slider_transition_delay]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['logo_slider_transition_delay'],
	'sanitize_callback'	=> 'parallax_frame_sanitize_number_range',
) );

$wp_customize->add_control( 'parallax_frame_theme_options[logo_slider_transition_delay]' , array(
	'active_callback' => 'parallax_frame_is_logo_slider_active',
	'description'     => esc_html__( 'seconds(s)', 'parallax-frame-pro' ),
	'input_attrs'     => array(
		'style' => 'width: 40px;'
		),
	'label'           => esc_html__( 'Transition Delay', 'parallax-frame-pro' ),
	'section'         => 'parallax_frame_logo_slider',
	'settings'        => 'parallax_frame_theme_options[logo_slider_transition_delay]',
) );

$wp_customize->add_setting( 'parallax_frame_theme_options[logo_slider_transition_length]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['logo_slider_transition_length'],
	'sanitize_callback'	=> 'parallax_frame_sanitize_number_range',
) );

$wp_customize->add_control( 'parallax_frame_theme_options[logo_slider_transition_length]' , array(
		'active_callback' => 'parallax_frame_is_logo_slider_active',
		'description'     => esc_html__( 'seconds(s)', 'parallax-frame-pro' ),
		'input_attrs'     => array(
			'style' => 'width: 40px;'
		),
		'label'           => esc_html__( 'Transition Length', 'parallax-frame-pro' ),
		'section'         => 'parallax_frame_logo_slider',
		'settings'        => 'parallax_frame_theme_options[logo_slider_transition_length]',
	)
);

$wp_customize->add_setting( 'parallax_frame_theme_options[logo_slider_title]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['logo_slider_title'],
	'sanitize_callback'	=> 'sanitize_text_field',
) );

$wp_customize->add_control( 'parallax_frame_theme_options[logo_slider_title]' , array(
	'active_callback' => 'parallax_frame_is_demo_logo_slider_inactive',
	'label'           => esc_html__( 'Title', 'parallax-frame-pro' ),
	'section'         => 'parallax_frame_logo_slider',
	'settings'        => 'parallax_frame_theme_options[logo_slider_title]',
) );

$wp_customize->add_setting( 'parallax_frame_theme_options[logo_slider_number]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['logo_slider_number'],
	'sanitize_callback'	=> 'parallax_frame_sanitize_number_range',
) );

$wp_customize->add_control( 'parallax_frame_theme_options[logo_slider_number]' , array(
	'active_callback' => 'parallax_frame_is_demo_logo_slider_inactive',
	'description'     => esc_html__( 'Save and refresh the page if No. of Slides is changed (Max no of slides is 20)', 'parallax-frame-pro' ),
	'input_attrs'     => array(
	'style'           => 'width: 45px;',
		'min'  => 0,
		'max'  => 20,
		'step' => 1,
	),
	'label'           => esc_html__( 'No of Items', 'parallax-frame-pro' ),
	'section'         => 'parallax_frame_logo_slider',
	'settings'        => 'parallax_frame_theme_options[logo_slider_number]',
	'type'            => 'number',
	)
);

$wp_customize->add_setting( 'parallax_frame_theme_options[logo_slider_visible_items]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['logo_slider_visible_items'],
	'sanitize_callback' => 'parallax_frame_sanitize_number_range',
) );

$wp_customize->add_control( 'parallax_frame_theme_options[logo_slider_visible_items]', array(
	'active_callback' => 'parallax_frame_is_demo_logo_slider_inactive',
	'input_attrs'     => array(
	'style'           => 'width: 45px;',
		'min'  => 0,
		'max'  => 5,
		'step' => 1,
	),
	'label'           => esc_html__( 'No of visible items', 'parallax-frame-pro' ),
	'section'         => 'parallax_frame_logo_slider',
	'settings'        => 'parallax_frame_theme_options[logo_slider_visible_items]',
	'type'            => 'number',
) );

$wp_customize->add_setting( 'parallax_frame_theme_options[logo_slider_select_category]', array(
	'capability'		=> 'edit_theme_options',
	'sanitize_callback'	=> 'parallax_frame_sanitize_category_list',
) );

$wp_customize->add_control( new parallax_frame_customize_dropdown_categories_control( $wp_customize, 'parallax_frame_logo_slider_select_category', array(
	'active_callback' => 'parallax_frame_is_logo_category_slider_active',
	'label'           => esc_html__( 'Select Categories', 'parallax-frame-pro' ),
	'name'            => 'parallax_frame_theme_options[logo_slider_select_category]',
	'section'         => 'parallax_frame_logo_slider',
	'settings'        => 'parallax_frame_theme_options[logo_slider_select_category]',
	'type'            => 'dropdown-categories',
) ) );

//loop for featured post sliders
for ( $i=1; $i <=  $options['logo_slider_number'] ; $i++ ) {
	//post content
	$wp_customize->add_setting( 'parallax_frame_theme_options[logo_slider_post_'. $i .']', array(
			'capability'		=> 'edit_theme_options',
			'sanitize_callback'	=> 'parallax_frame_sanitize_page',
		)
	);

	$wp_customize->add_control( 'parallax_frame_logo_slider_post_'. $i, array(
		'active_callback' => 'parallax_frame_is_logo_post_slider_active',
		'input_attrs'     => array( 'style' => 'width: 100px;'),
		'label'           => esc_html__( 'Post', 'parallax-frame-pro' ) . ' ' . $i ,
		'section'         => 'parallax_frame_logo_slider',
		'settings'        => 'parallax_frame_theme_options[logo_slider_post_'. $i .']',
		'type'            => 'text',
	) );

	//page content
	$wp_customize->add_setting( 'parallax_frame_theme_options[logo_slider_page_'. $i .']', array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'parallax_frame_sanitize_page',
	) );

	$wp_customize->add_control( 'parallax_frame_logo_slider_page_'. $i, array(
		'active_callback' => 'parallax_frame_is_logo_page_slider_active',
		'label'           => esc_html__( 'Page', 'parallax-frame-pro' ) . ' ' . $i ,
		'section'         => 'parallax_frame_logo_slider',
		'settings'        => 'parallax_frame_theme_options[logo_slider_page_'. $i .']',
		'type'            => 'dropdown-pages',
	) );

	$wp_customize->add_setting( 'parallax_frame_theme_options[logo_slider_note_'. $i .']', array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( new parallax_frame_note_control( $wp_customize, 'logo_slider_note_'. $i, array(
		'active_callback' => 'parallax_frame_is_logo_image_slider_active',
		'label'           => esc_html__( 'Slide #', 'parallax-frame-pro' ) . $i,
		'section'         => 'parallax_frame_logo_slider',
		'settings'        => 'parallax_frame_theme_options[logo_slider_note_'. $i .']',
		'type'            => 'description',
	) ) );

	$wp_customize->add_setting( 'parallax_frame_theme_options[logo_slider_image_'. $i .']', array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'parallax_frame_sanitize_image',
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'logo_slider_image_'. $i , array(
		'active_callback' => 'parallax_frame_is_logo_image_slider_active',
		'label'           => esc_html__( 'Image', 'parallax-frame-pro' ),
		'section'         => 'parallax_frame_logo_slider',
		'settings'        => 'parallax_frame_theme_options[logo_slider_image_'. $i .']',
	) ) );

	$wp_customize->add_setting( 'parallax_frame_theme_options[logo_slider_title_'. $i .']', array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'esc_url_raw',
	) );

	$wp_customize->add_control(  'parallax_frame_theme_options[logo_slider_title_'. $i .']', array(
		'active_callback' => 'parallax_frame_is_logo_image_slider_active',
		'label'           => esc_html__( 'Title/Image Alt', 'parallax-frame-pro' ),
		'section'         => 'parallax_frame_logo_slider',
		'settings'        => 'parallax_frame_theme_options[logo_slider_title_'. $i .']',
	) );

	$wp_customize->add_setting( 'parallax_frame_theme_options[logo_slider_link_'. $i .']', array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'esc_url_raw',
	) );

	$wp_customize->add_control(  'parallax_frame_theme_options[logo_slider_link_'. $i .']', array(
		'active_callback' => 'parallax_frame_is_logo_image_slider_active',
		'label'           => esc_html__( 'Link', 'parallax-frame-pro' ),
		'section'         => 'parallax_frame_logo_slider',
		'settings'        => 'parallax_frame_theme_options[logo_slider_link_'. $i .']',
	) );

	$wp_customize->add_setting( 'parallax_frame_theme_options[logo_slider_target_'. $i .']', array(
        'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'parallax_frame_sanitize_checkbox',
	) );

	$wp_customize->add_control(  'parallax_frame_theme_options[logo_slider_target_'. $i .']', array(
		'active_callback' => 'parallax_frame_is_logo_image_slider_active',
		'label'           => esc_html__( 'Check to Open Link in New Window/Tab', 'parallax-frame-pro' ),
		'section'         => 'parallax_frame_logo_slider',
		'settings'        => 'parallax_frame_theme_options[logo_slider_target_'. $i .']',
		'type'            => 'checkbox',
    ) );
}
// Logo Slider End